import setuptools

setuptools.setup(
    name="icims_a11y_tools",
    version="0.0.2",
    author="chrisding",
    description="The icims a11y scanner package",
    packages=setuptools.find_packages(),
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
)